pub enum GoElementType {
Show 161 variants
SourceFile,
PackageClause,
ImportDeclaration,
ImportSpec,
FunctionDeclaration,
Receiver,
ParameterList,
ParameterDecl,
Block,
VariableDeclaration,
VariableSpec,
ConstDeclaration,
ConstSpec,
TypeDeclaration,
TypeSpec,
StructType,
FieldDeclList,
FieldDecl,
InterfaceType,
MethodSpecList,
MethodSpec,
ExpressionList,
AssignmentStatement,
ShortVarDecl,
ReturnStatement,
IfStatement,
ForStatement,
SwitchStatement,
ExprCaseClause,
TypeSwitchStatement,
TypeCaseClause,
SelectStatement,
CommClause,
GoStatement,
DeferStatement,
CallExpression,
IndexExpression,
SelectorExpression,
SliceExpression,
TypeAssertion,
UnaryExpression,
BinaryExpression,
LiteralValue,
ElementList,
KeyedElement,
IntLiteral,
FloatLiteral,
StringLiteral,
RuneLiteral,
BoolLiteral,
Identifier,
Break,
Case,
Chan,
Const,
Continue,
Default,
Defer,
Else,
Fallthrough,
For,
Func,
Go,
Goto,
If,
Import,
Interface,
Map,
Package,
Range,
Return,
Select,
Struct,
Switch,
Type,
Var,
Bool,
Byte,
Complex64,
Complex128,
ErrorType,
Float32,
Float64,
Int,
Int8,
Int16,
Int32,
Int64,
Rune,
String,
Uint,
Uint8,
Uint16,
Uint32,
Uint64,
Uintptr,
NilLiteral,
NumberLiteral,
CharLiteral,
Plus,
Minus,
Star,
Slash,
Percent,
Ampersand,
Pipe,
Caret,
LeftShift,
RightShift,
AmpersandCaret,
PlusAssign,
MinusAssign,
StarAssign,
SlashAssign,
PercentAssign,
AmpersandAssign,
PipeAssign,
CaretAssign,
XorAssign,
LeftShiftAssign,
RightShiftAssign,
AmpersandCaretAssign,
AndAssign,
OrAssign,
AndNotAssign,
AndNot,
LogicalAnd,
LogicalOr,
And,
Or,
Arrow,
LeftArrow,
Increment,
Decrement,
Equal,
Less,
Greater,
Assign,
LogicalNot,
Not,
NotEqual,
LessEqual,
GreaterEqual,
ColonAssign,
Define,
Ellipsis,
LeftParen,
RightParen,
LeftBracket,
RightBracket,
LeftBrace,
RightBrace,
Comma,
Period,
Dot,
Semicolon,
Colon,
Whitespace,
Comment,
Eof,
Error,
}Expand description
Element types for the Go language.
Variants
SourceFile
A source file.
PackageClause
A package clause.
ImportDeclaration
An import declaration.
ImportSpec
An import spec.
FunctionDeclaration
A function declaration.
Receiver
A receiver declaration.
ParameterList
A parameter list.
ParameterDecl
A parameter declaration.
Block
A code block.
VariableDeclaration
A variable declaration.
VariableSpec
A variable spec.
ConstDeclaration
A constant declaration.
ConstSpec
A constant spec.
TypeDeclaration
A type declaration.
TypeSpec
A type spec.
StructType
A struct type.
FieldDeclList
A field declaration list.
FieldDecl
A field declaration.
InterfaceType
An interface type.
MethodSpecList
A method spec list.
MethodSpec
A method spec.
ExpressionList
An expression list.
AssignmentStatement
An assignment statement.
ShortVarDecl
A short variable declaration.
ReturnStatement
A return statement.
IfStatement
An if statement.
ForStatement
A for statement.
SwitchStatement
A switch statement.
ExprCaseClause
An expression case clause.
TypeSwitchStatement
A type switch statement.
TypeCaseClause
A type case clause.
SelectStatement
A select statement.
CommClause
A communication clause.
GoStatement
A go statement.
DeferStatement
A defer statement.
CallExpression
A function call expression.
IndexExpression
An index expression.
SelectorExpression
A selector expression.
SliceExpression
A slice expression.
TypeAssertion
A type assertion expression.
UnaryExpression
A unary expression.
BinaryExpression
A binary expression.
LiteralValue
A literal value.
ElementList
An element list.
KeyedElement
A keyed element.
IntLiteral
An integer literal.
FloatLiteral
A floating-point literal.
StringLiteral
A string literal.
RuneLiteral
A rune literal.
BoolLiteral
A boolean literal.
Identifier
An identifier.
Break
break keyword.
Case
case keyword.
Chan
chan keyword.
Const
const keyword.
Continue
continue keyword.
Default
default keyword.
Defer
defer keyword.
Else
else keyword.
Fallthrough
fallthrough keyword.
For
for keyword.
Func
func keyword.
Go
go keyword.
Goto
goto keyword.
If
if keyword.
Import
import keyword.
Interface
interface keyword.
Map
map keyword.
Package
package keyword.
Range
range keyword.
Return
return keyword.
Select
select keyword.
Struct
struct keyword.
Switch
switch keyword.
Type
type keyword.
Var
var keyword.
Bool
bool type.
Byte
byte type.
Complex64
complex64 type.
Complex128
complex128 type.
ErrorType
error type.
Float32
float32 type.
Float64
float64 type.
Int
int type.
Int8
int8 type.
Int16
int16 type.
Int32
int32 type.
Int64
int64 type.
Rune
rune type.
String
string type.
Uint
uint type.
Uint8
uint8 type.
Uint16
uint16 type.
Uint32
uint32 type.
Uint64
uint64 type.
Uintptr
uintptr type.
NilLiteral
nil literal.
NumberLiteral
A number literal.
CharLiteral
A character literal.
Plus
+.
Minus
-.
Star
*.
Slash
/.
Percent
%.
Ampersand
&.
Pipe
|.
Caret
^.
LeftShift
<<.
RightShift
>>.
AmpersandCaret
&^.
PlusAssign
+=.
MinusAssign
-=.
StarAssign
*=.
SlashAssign
/=.
PercentAssign
%=.
AmpersandAssign
&=.
PipeAssign
|=.
CaretAssign
^=.
XorAssign
^= (alias).
LeftShiftAssign
<<=.
RightShiftAssign
>>=.
AmpersandCaretAssign
&^=.
AndAssign
&= (alias).
OrAssign
|= (alias).
AndNotAssign
&^= (alias).
AndNot
&^ (alias).
LogicalAnd
&&.
LogicalOr
||.
And
&& (alias).
Or
|| (alias).
Arrow
<-.
LeftArrow
<- (alias).
Increment
++.
Decrement
--.
Equal
==.
Less
<.
Greater
>.
Assign
=.
LogicalNot
!.
Not
! (alias).
NotEqual
!=.
LessEqual
<=.
GreaterEqual
>=.
ColonAssign
:=.
Define
:= (alias).
Ellipsis
....
LeftParen
(.
RightParen
).
LeftBracket
[.
RightBracket
].
LeftBrace
{.
RightBrace
}.
Comma
,.
Period
..
Dot
. (alias).
Semicolon
;.
Colon
:.
Whitespace
Whitespace.
Comment
Comment.
Eof
End of stream marker.
Error
Error element.
Implementations
Sourceimpl GoElementType
impl GoElementType
Sourcepub fn is_ignored(&self) -> bool
pub fn is_ignored(&self) -> bool
Returns true if the element is whitespace or a comment.
Sourcepub fn is_keyword(&self) -> bool
pub fn is_keyword(&self) -> bool
Returns true if the element is a Go keyword.
Sourcepub fn is_literal(&self) -> bool
pub fn is_literal(&self) -> bool
Returns true if the element is a Go literal.
Sourcepub fn is_operator(&self) -> bool
pub fn is_operator(&self) -> bool
Returns true if the element is a Go operator.