pub enum GoTokenType {
Show 160 variants
SourceFile,
PackageClause,
ImportDeclaration,
ImportSpec,
FunctionDeclaration,
ParameterList,
ParameterDecl,
Block,
VariableDeclaration,
VariableSpec,
ConstDeclaration,
ConstSpec,
TypeDeclaration,
TypeSpec,
StructType,
FieldDeclList,
FieldDecl,
InterfaceType,
MethodSpecList,
MethodSpec,
ExpressionList,
AssignmentStatement,
ShortVarDecl,
ReturnStatement,
IfStatement,
ForStatement,
SwitchStatement,
ExprCaseClause,
TypeSwitchStatement,
TypeCaseClause,
SelectStatement,
CommClause,
GoStatement,
DeferStatement,
CallExpression,
IndexExpression,
SelectorExpression,
SliceExpression,
TypeAssertion,
UnaryExpression,
BinaryExpression,
LiteralValue,
ElementList,
KeyedElement,
IntLiteral,
FloatLiteral,
StringLiteral,
RuneLiteral,
BoolLiteral,
Identifier,
Break,
Case,
Chan,
Const,
Continue,
Default,
Defer,
Else,
Fallthrough,
For,
Func,
Go,
Goto,
If,
Import,
Interface,
Map,
Package,
Range,
Return,
Select,
Struct,
Switch,
Type,
Var,
Bool,
Byte,
Complex64,
Complex128,
ErrorType,
Float32,
Float64,
Int,
Int8,
Int16,
Int32,
Int64,
Rune,
String,
Uint,
Uint8,
Uint16,
Uint32,
Uint64,
Uintptr,
NilLiteral,
NumberLiteral,
CharLiteral,
Plus,
Minus,
Star,
Slash,
Percent,
Ampersand,
Pipe,
Caret,
LeftShift,
RightShift,
AmpersandCaret,
PlusAssign,
MinusAssign,
StarAssign,
SlashAssign,
PercentAssign,
AmpersandAssign,
PipeAssign,
CaretAssign,
XorAssign,
LeftShiftAssign,
RightShiftAssign,
AmpersandCaretAssign,
AndAssign,
OrAssign,
AndNotAssign,
AndNot,
LogicalAnd,
LogicalOr,
And,
Or,
Arrow,
LeftArrow,
Increment,
Decrement,
Equal,
Less,
Greater,
Assign,
LogicalNot,
Not,
NotEqual,
LessEqual,
GreaterEqual,
ColonAssign,
Define,
Ellipsis,
LeftParen,
RightParen,
LeftBracket,
RightBracket,
LeftBrace,
RightBrace,
Comma,
Period,
Dot,
Semicolon,
Colon,
Whitespace,
Comment,
Eof,
Error,
}Expand description
Token types for the Go language.
Variants
SourceFile
A source file node.
PackageClause
A package clause node.
ImportDeclaration
An import declaration node.
ImportSpec
An import spec node.
FunctionDeclaration
A function declaration node.
ParameterList
A parameter list node.
ParameterDecl
A parameter declaration node.
Block
A code block node.
VariableDeclaration
A variable declaration node.
VariableSpec
A variable spec node.
ConstDeclaration
A constant declaration node.
ConstSpec
A constant spec node.
TypeDeclaration
A type declaration node.
TypeSpec
A type spec node.
StructType
A struct type node.
FieldDeclList
A field declaration list node.
FieldDecl
A field declaration node.
InterfaceType
An interface type node.
MethodSpecList
A method spec list node.
MethodSpec
A method spec node.
ExpressionList
An expression list node.
AssignmentStatement
An assignment statement node.
ShortVarDecl
A short variable declaration node.
ReturnStatement
A return statement node.
IfStatement
An if statement node.
ForStatement
A for statement node.
SwitchStatement
A switch statement node.
ExprCaseClause
An expression case clause node.
TypeSwitchStatement
A type switch statement node.
TypeCaseClause
A type case clause node.
SelectStatement
A select statement node.
CommClause
A communication clause node.
GoStatement
A go statement node.
DeferStatement
A defer statement node.
CallExpression
A function call expression node.
IndexExpression
An index expression node.
SelectorExpression
A selector expression node.
SliceExpression
A slice expression node.
TypeAssertion
A type assertion expression node.
UnaryExpression
A unary expression node.
BinaryExpression
A binary expression node.
LiteralValue
A literal value node.
ElementList
An element list node.
KeyedElement
A keyed element node.
IntLiteral
An integer literal.
FloatLiteral
A floating-point literal.
StringLiteral
A string literal.
RuneLiteral
A rune literal.
BoolLiteral
A boolean literal.
Identifier
An identifier.
Break
break keyword.
Case
case keyword.
Chan
chan keyword.
Const
const keyword.
Continue
continue keyword.
Default
default keyword.
Defer
defer keyword.
Else
else keyword.
Fallthrough
fallthrough keyword.
For
for keyword.
Func
func keyword.
Go
go keyword.
Goto
goto keyword.
If
if keyword.
Import
import keyword.
Interface
interface keyword.
Map
map keyword.
Package
package keyword.
Range
range keyword.
Return
return keyword.
Select
select keyword.
Struct
struct keyword.
Switch
switch keyword.
Type
type keyword.
Var
var keyword.
Bool
bool type.
Byte
byte type.
Complex64
complex64 type.
Complex128
complex128 type.
ErrorType
error type.
Float32
float32 type.
Float64
float64 type.
Int
int type.
Int8
int8 type.
Int16
int16 type.
Int32
int32 type.
Int64
int64 type.
Rune
rune type.
String
string type.
Uint
uint type.
Uint8
uint8 type.
Uint16
uint16 type.
Uint32
uint32 type.
Uint64
uint64 type.
Uintptr
uintptr type.
NilLiteral
nil literal.
NumberLiteral
A number literal.
CharLiteral
A character literal.
Plus
+.
Minus
-.
Star
*.
Slash
/.
Percent
%.
Ampersand
&.
Pipe
|.
Caret
^.
LeftShift
<<.
RightShift
>>.
AmpersandCaret
&^.
PlusAssign
+=.
MinusAssign
-=.
StarAssign
*=.
SlashAssign
/=.
PercentAssign
%=.
AmpersandAssign
&=.
PipeAssign
|=.
CaretAssign
^=.
XorAssign
^= (alias).
LeftShiftAssign
<<=.
RightShiftAssign
>>=.
AmpersandCaretAssign
&^=.
AndAssign
&= (alias).
OrAssign
|= (alias).
AndNotAssign
&^= (alias).
AndNot
&^ (alias).
LogicalAnd
&&.
LogicalOr
||.
And
&& (alias).
Or
|| (alias).
Arrow
<-.
LeftArrow
<- (alias).
Increment
++.
Decrement
--.
Equal
==.
Less
<.
Greater
>.
Assign
=.
LogicalNot
!.
Not
! (alias).
NotEqual
!=.
LessEqual
<=.
GreaterEqual
>=.
ColonAssign
:=.
Define
:= (alias).
Ellipsis
....
LeftParen
(.
RightParen
).
LeftBracket
[.
RightBracket
].
LeftBrace
{.
RightBrace
}.
Comma
,.
Period
..
Dot
. (alias).
Semicolon
;.
Colon
:.
Whitespace
Whitespace.
Comment
Comment.
Eof
End of stream marker.
Error
Error element.
Implementations
Sourceimpl GoTokenType
impl GoTokenType
Sourcepub fn is_ignored(&self) -> bool
pub fn is_ignored(&self) -> bool
Returns true if this token type represents ignored trivia (whitespace or comments).
Sourcepub fn is_keyword(&self) -> bool
pub fn is_keyword(&self) -> bool
Returns true if this token type represents a Go keyword.